@@ -40,7 +40,7 @@ from .urls_patterns import URL_ADMIN_SERVER_INFO, URL_ADMIN_CLIENT_AUTHZ_RESOURC
     URL_ADMIN_USER_CLIENT_ROLES_AVAILABLE, URL_ADMIN_USERS, URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID, URL_ADMIN_CLIENT_AUTHZ_POLICIES, \
     URL_ADMIN_CLIENT_AUTHZ_POLICIES_ID, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS_ID, \
     URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL, \
-    URL_ADMIN_DEFAULT_GROUPS, URL_ADMIN_GROUP_REALM_ROLES
+    URL_ADMIN_DEFAULT_GROUPS, URL_ADMIN_GROUP_REALM_ROLES, URL_ADMIN_USER_REALM_ROLES_COMPOSITE
 
 def serialize(obj):
     """JSON serializer for objects not serializable by default json code"""
@@ -997,6 +997,21 @@ class KeycloakAdmin:
         params_path = {"realm-name": self.realm_name, "id": user_id}
         data_raw = self.connection.raw_get(URL_ADMIN_USER_REALM_ROLES.format(**params_path))
         return raise_error_from_response(data_raw, KeycloakGetError)
+    
+    def get_realm_composite_roles_of_user(self, user_id):
+        """
+        Get user's roles for the realm
+
+        RoleRepresentation
+        http://www.keycloak.org/docs-api/3.3/rest-api/index.html#_rolerepresentation
+
+        :user_id: user's id
+        :return: Keycloak server response (RoleRepresentation)
+        """
+
+        params_path = {"realm-name": self.realm_name, "id": user_id}
+        data_raw = self.connection.raw_get(URL_ADMIN_USER_REALM_ROLES_COMPOSITE.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError)
 
     def create_realm_role(self, payload, skip_exists=False):
         """
